<?php
/** Maithili (मैथिली)
 *
 * @ingroup Language
 * @file
 *
 * @author Ggajendra
 * @author Meno25
 */

$fallback = 'hi';

$messages = array(
# User preference toggles
'tog-underline'           => 'लिंककेँ रेखांकित करू:',
'tog-highlightbroken'     => 'टूटल श्रृंखला <a href="" class="new">एना देखाऊ</a> (आकि फेर: एना देखाऊ<a href="" class="internal">?</a>).',
'tog-justify'             => 'सुगढ़ बनाऊ',
'tog-hideminor'           => 'सन्निकट परिवर्त्तनमे छोट परिवर्त्तन नुकाऊ',
'tog-extendwatchlist'     => 'ध्यानसूचीमे सभ परिवर्तन देखाऊ',
'tog-usenewrc'            => 'बढ़ल सन्निकट परिवर्त्तन (जावास्क्रीप्ट)',
'tog-numberheadings'      => 'शीर्षक स्वयं-क्रमांकित करू',
'tog-showtoolbar'         => 'संपादन ओजारपेटी देखाऊ (जावास्क्रीप्ट)',
'tog-editondblclick'      => 'दू बेर क्लीक कए पन्ना संपादित करू (जावास्क्रीप्ट)',
'tog-editsection'         => '[संपादित करू] श्रृंखला द्वारा विभाग संपादनक आज्ञा दिअ',
'tog-showtoc'             => 'अनुक्रम देखाऊ (जाहि पृष्ठ पर तीनसँ बेशी विभाग होए)',
'tog-editwidth'           => 'सँपादन पेटी पूर्ण चौरस देखाऊ',
'tog-watchdefault'        => 'हमर संपादित पृष्ठ हमर साकांक्ष सूचीमे देखाऊ',
'tog-watchdeletion'       => 'हमरा द्वारा हटाओल पृष्ठ हमर साकांक्ष सूचीमे राखू',
'tog-previewontop'        => 'संपादन पेटीक ऊपर दृश्य देखाऊ',
'tog-nocache'             => 'पन्ना प्रतीक्षा गह्वरमे नहि राखू',
'tog-enotifusertalkpages' => 'हमर सदस्य वार्ता पृष्ठ पर भेल परिवर्त्तनक हेतु हमरा ई-मेल करथि',
'tog-enotifminoredits'    => 'छोट परिवर्त्तनक हेतु सेहो हमरा ई-मेल पठाऊ',
'tog-fancysig'            => 'अपरिपक्व हस्ताक्षर (स्वचालित श्रृंखलाक बिना)',
'tog-externaldiff'        => 'पुरान संस्करणमे अंतर देखेबाक हेतु बाहरक प्रणालीक प्रयोग करू',

# Dates
'sun'           => 'रवि',
'mon'           => 'सोम',
'tue'           => 'मंगल',
'wed'           => 'बुध',
'thu'           => 'बृह.',
'fri'           => 'शुक्र',
'sat'           => 'शनि',
'january'       => 'जनवरी',
'february'      => 'फरबरी',
'march'         => 'मार्च',
'april'         => 'अप्रैल',
'may_long'      => 'मई',
'june'          => 'जून',
'july'          => 'जुलाइ',
'august'        => 'अगस्त',
'september'     => 'सितम्बर',
'october'       => 'अक्टूबर',
'november'      => 'नवंबर',
'december'      => 'दिसंबर',
'january-gen'   => 'जनवरी',
'february-gen'  => 'फरबरी',
'march-gen'     => 'मार्च',
'april-gen'     => 'अप्रैल',
'may-gen'       => 'मई',
'june-gen'      => 'जून',
'july-gen'      => 'जुलाई',
'august-gen'    => 'अगस्त',
'september-gen' => 'सितंबर',
'october-gen'   => 'अकटूबर',
'november-gen'  => 'नवंबर',
'december-gen'  => 'दिसंबर',
'jan'           => 'जन.',
'feb'           => 'फर.',
'mar'           => 'मा.',
'apr'           => 'अप.',
'may'           => 'मई',
'jun'           => 'जू.',
'jul'           => 'जु.',
'aug'           => 'अग.',
'sep'           => 'सित.',
'oct'           => 'अक्टू.',
'nov'           => 'नव.',
'dec'           => 'दिस.',

'newwindow' => '(नव खिड़कीसँ खुजैछ)',
'cancel'    => 'समाप्त',
'mytalk'    => 'हमर वार्त्ता',

'errorpagetitle'   => 'गलती',
'tagline'          => 'कतयसँ {{SITENAME}}',
'help'             => 'मदति',
'search'           => 'ताकू',
'searchbutton'     => 'ताकू',
'searcharticle'    => 'जाऊ',
'history'          => 'पन्नाक इतिहास',
'printableversion' => 'प्रिंट करबा योग्य',
'permalink'        => 'स्थायी लिंक',
'edit'             => 'संपादन',
'editthispage'     => 'एहि पृष्ठक संपादन',
'talkpage'         => 'एहि पृष्ठ पर वार्त्तालाप',
'talkpagelinktext' => 'कहू',
'personaltools'    => 'व्यक्तिगत उपकरण',
'talk'             => 'वर्त्तालाप',
'views'            => 'दृष्टि',
'toolbox'          => 'उपकरण-बक्सा',
'redirectedfrom'   => '(एतयसँ बहटारल $1)',
'jumpto'           => 'जाऊ:',
'jumptonavigation' => 'हेलू',
'jumptosearch'     => 'ताकू',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'विषयमे {{SITENAME}}',
'aboutpage'            => 'Project:विवरण',
'copyrightpage'        => '{{ns:project}}:सर्वाधिकार',
'disclaimers'          => 'अनाधिकार घोषणा',
'disclaimerpage'       => 'Project:अनाधिकार घोषणा',
'edithelp'             => 'संपादन सहयोग',
'edithelppage'         => 'Help:संपादन',
'mainpage'             => 'सम्मुख पन्ना',
'mainpage-description' => 'सम्मुख पन्ना',
'privacy'              => 'गोपनीयताक नियम',
'privacypage'          => 'Project:गोपनीयता नियम',

'retrievedfrom'   => 'प्राप्ति स्थल "$1"',
'editsection'     => 'संपादन करू',
'editsectionhint' => 'संपादन शाखा: $1',
'toc'             => 'विषय-सूची',
'showtoc'         => 'देखाऊ',
'hidetoc'         => 'नुकाऊ',
'site-rss-feed'   => '$1 आरएसएस फीड',
'site-atom-feed'  => '$1 अणु फीड',

# Login and logout pages
'nav-login-createaccount' => 'सदस्य लॉग इन',
'userlogin'               => 'लॉग इन / खेसरा बनाऊ',
'userlogout'              => 'फेर आयब',

# Edit page toolbar
'bold_sample'     => 'गँहीर लेखन',
'bold_tip'        => 'गँहीर लेखन',
'italic_sample'   => 'कटि लेखन',
'italic_tip'      => 'क़टि लेखन',
'link_sample'     => 'लिंक उपाधि',
'link_tip'        => 'अंतरंग इशारा',
'extlink_sample'  => 'http://www.example.com लिंक उपाधि',
'extlink_tip'     => 'बहरी लिंक (यादि राखू http:// उपसर्ग)',
'headline_sample' => 'मुख्यपंक्ति लेखन',
'headline_tip'    => 'स्तर 2 मुख्यपंक्ति',
'math_sample'     => 'सूत्र समाहित करू',
'math_tip'        => 'गणितीय सूत्र (LaTeX)',
'nowiki_sample'   => 'फॉर्मेट विहीन लेख एतय',
'nowiki_tip'      => 'विकी फॉरमेटिंगकेँ छोड़ू',
'image_tip'       => 'समाहित चित्र',
'media_tip'       => 'मीडिया फाइल लिंक',
'sig_tip'         => 'अहाँक हस्ताक्षर समयक मोहरक संग',
'hr_tip'          => 'अक्षांशीय पंक्ति (अल्प उपयोग)',

# Edit pages
'summary'              => 'सारांश:',
'subject'              => 'विषय/मुख्यपंक्ति:',
'minoredit'            => 'अल्प संपादन',
'watchthis'            => 'एहि पृष्ठकेँ देखू',
'showpreview'          => 'पूर्वप्रदर्शन',
'showdiff'             => 'परिवर्त्तन देखाऊ',
'copyrightwarning'     => 'कृपा कय बुझू जे सभटा योगदान {{SITENAME}} ई बुझि कय देल जा रहल अछि जे ई निम्नांकितक अंतर्गत अछि $2 (देखू $1 जनकारीक हेतु). जौँ अहाँ चाहैत छी जी अहाँक रचना बिना रोकटोकक संपादित नहि हो किंवा बाँटल नहि जाय, तँ एकर योगदान एतय नहि करू। <br />
एतय अहाँ ईहो सप्पत खाइत छी जी ई अहाँक अपन रचना छी आकि अहाँ एकरा कोनो सार्वजनिक डोमेन किंवा ओह्ने कोनो मँगनीक संदर्भ-स्थलसँ कॉपी कएने छी। 
< दृढ़> सर्वाधिकार सुरक्षित कार्य एतय नहि दी।!</दृढ़>',
'templatesusedpreview' => 'एहि पूर्वप्रदर्शनमे प्रयुक्त मास्टरफाइल:',
'template-protected'   => '(सुरक्षित)',

# History pages
'revisionasof'     => 'अंतिम परिवर्त्तन  $1',
'previousrevision' => '←पुरान परिवर्त्तन',
'cur'              => 'हीन',
'last'             => 'अंतिम',

# Diffs
'lineno'   => 'पंक्त्ति $1:',
'editundo' => 'असंपादन',

# Search results
'noexactmatch' => "'''\"\$1\" नामसँ कोनो लेख नहि अछि।''' अहाँ ई लेख [[:\$1|बना सकैत छी]]।",
'powersearch'  => 'त्वरित खोज',

# Preferences page
'preferences'   => 'विकल्प',
'mypreferences' => 'हमर नीकगर',

# Recent changes
'nchanges'        => '$1 {{PLURAL:$1|परिवर्त्तन|परिवर्त्तन}}',
'rcnote'          => "नीचाँ $3 तक पहिलुका {{PLURAL:$2|'''१''' दिनमे भेल|'''$2''' दिनमे भेल}} अंतिम $1 बदलाव {{PLURAL:$1|देल अछि|देल अछि}}।",
'rcshowhideminor' => '$1 अल्प संपादन',
'rclinks'         => 'देखाऊ अंतिम $1 परिवर्त्तन अंतिम $2 दिनमे<br />$3',
'diff'            => 'अंतर',
'hist'            => 'इति.',
'hide'            => 'नुकाऊ',
'minoreditletter' => 'अ',
'newpageletter'   => 'न',
'boteditletter'   => 'ब',

# Recent changes linked
'recentchangeslinked'       => 'संबंधित परिवर्त्तन',
'recentchangeslinked-title' => '"$1" मे भेल परिवर्तन',

# Upload
'upload'        => 'फाइल अपलोड करू',
'uploadbtn'     => 'फाइल अपलोड',
'uploadedimage' => 'अपलोड भेल "[[$1]]"',

# File description page
'filehist'   => 'फाइल इतिहास',
'imagelinks' => 'लिंक्स',

# Random page
'randompage' => 'अव्यवस्थित पृष्ठ',

# Miscellaneous special pages
'nbytes'      => '$1 {{PLURAL:$1|बाइट|बाइट्स}}',
'prefixindex' => 'लगाऊ सूची',

# Special:Log
'all-logs-page' => 'सभटा लॉग',

# Special:AllPages
'alphaindexline' => '$1 to $2',

# Watchlist
'mywatchlist' => 'हमर साकांक्ष-सूची',
'watch'       => 'ताकिमे',
'unwatch'     => 'छोड़ू',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'ताकिमे...',
'unwatching' => 'छोड़ल ...',

# Protect
'protectlogpage' => 'सुरक्षा लॉग',
'prot_1movedto2' => '[[$1]] गेल एतय [[$2]]',

# Namespace form on various pages
'blanknamespace' => '(मुख्य)',

# Contributions
'mycontris' => 'हमर योगदान',

# What links here
'whatlinkshere'       => 'एतय कोन लिंक अछि',
'whatlinkshere-links' => '← लिंक',

# Block/unblock
'blocklink'    => 'प्रतिबंधित',
'contribslink' => 'योगदान',

# Move page
'1movedto2' => '[[$1]] गेल एतय [[$2]]',

# Thumbnails
'thumbnail-more' => 'पैघ',

# Import log
'importlogpage' => 'लॉगक आयात',

# Tooltip help for the actions
'tooltip-pt-userpage'     => 'हमर खेसरा पन्ना',
'tooltip-pt-mytalk'       => 'हमर वार्त्ता पृष्ठ',
'tooltip-pt-preferences'  => 'हमर मोनपसंद',
'tooltip-pt-watchlist'    => 'पन्ना सभ जकर परिवर्त्तन पर अहाँक नजरि अछि',
'tooltip-pt-mycontris'    => 'हमर योगदानक सूची',
'tooltip-pt-login'        => 'लॉग इन करब नीक, परञ्च आवश्यक नहि.',
'tooltip-pt-logout'       => 'फेर आयब',
'tooltip-ca-talk'         => 'विषयसूचीक पन्नाक संबंधमे वर्त्तालाप',
'tooltip-ca-edit'         => 'अहाँ एहि पन्नाकेँ संपादित कए सकैत छी। कृपया सुरक्षित करबासँ पहिने पूर्वप्रदर्शन बटम उपयोग करू।',
'tooltip-search'          => 'ताकू {{SITENAME}}',
'tooltip-n-mainpage'      => 'मुख्य-पृष्ठ केँ देखू',
'tooltip-n-portal'        => 'प्रोजेक्टक विषयमे,अहाँ की कए सकैत छी,वस्तु प्राप्ति स्थल',
'tooltip-n-currentevents' => 'लगक घटनाक विषयमे आधार सूचना प्राप्त करू।',
'tooltip-n-recentchanges' => 'विकीमे लगक परिवर्त्तनक सूची.',
'tooltip-n-randompage'    => 'कोनो अनिर्धारित पन्ना लोड करू',
'tooltip-n-help'          => 'प्राप्त करबाक स्थान.',
'tooltip-t-whatlinkshere' => 'सभटा विकी-पन्नाक सूची जकर एतय लिंक अछि',
'tooltip-t-upload'        => 'चित्र आकि मीडिया फाइलकेँ अपलोड करू',
'tooltip-t-specialpages'  => 'सभटा विशेष पन्नाक सूची',
'tooltip-save'            => 'अपन परिवर्त्तनके सुरक्षित करू',
'tooltip-preview'         => 'परिवर्त्तनक प्रदर्शन, संजोगबाक पहिने एकर प्रयोग करू!',
'tooltip-diff'            => 'देखाऊ जे परिवर्त्तन अहाँ एहि लेखमे कएलहुँ।',

# Bad image list
'bad_image_list' => 'फॉर्मेट निम्न प्रकारेँ अछि:

मात्र सूचीबद्ध सामग्री (* सँ प्रारम्भ होय बला पंक्त्ति) विचारनीय अछि। पंक्त्तिक प्रथम लिंक आवश्यक रूपसँ खराब चित्रक लिंक होयबाक चाही। 

ओही पंक्त्तिक कोनो आर लिंक अपवाद स्वरूप अछि, उदाहरणस्वरूप पन्ना जतय चित्र पंक्त्तिअहि पर होय।',

# Special:SpecialPages
'specialpages' => 'विशेष पन्ना',

);
